==> identity-apps-1.0.117-source-release.zip: identity-apps-1.0.117/modules/i18n/src/translations/ta-IN/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "அணுகல்",
    active: "செயல்பாட்டில் உள்ள",
    add: "சேர்",
    all: "அனைத்தும்",
    applicationName: "செயலியின் பெயர்",
    applications: "செயலிகள்",
    approvalStatus: "அனுமதி நிலை",
    approve: "அனுமதி",
    assignees: "அளிக்கப்பட்டவர்கள்",
    browser: "உலாவி",
    cancel: "இரத்து செய்",
    challengeQuestionNumber: "சவால் வினா {{number}}",
    change: "மாற்று",
    claim: "கோர்",
    completed: "பூரணப்படுத்தப்பட்டவை",
    configure: "கட்டமை",
    contains: "கொண்டுள்ளது",
    continue: "தொடர்",
    createdOn: "உருவாக்கப்பட்ட தினம்",
    dangerZone: "ஆபத்து மண்டலம்",
    delete: "அழி",
    description: "விபரம்",
    deviceModel: "கருவி மாதிரி",
    edit: "திருத்து",
    endsWith: "முடிவடைவது",
    equals: "சமன்",
    filter: "வடிகட்டு",
    goBackHome: "முகப்புக்கு செல்",
    help: "உதவி",
    hidePassword: "கடவுச்சொல்லை மறை",
    initiator: "கருத்தா",
    ipAddress: "ip முகவரி",
    lastAccessed: "இறுதி அணுகல்",
    lastSeen: "இறுதி நுழைவு",
    loginTime: "நுழைந்த நேரம்",
    logout: "வெளியேறு",
    more: "மேலும்",
    name: "பெயர்",
    operatingSystem: "இயங்கு தளம்",
    operations: "செயற்பாடுகள்",
    overview: "கண்ணோட்டம்",
    personalInfo: "பயனர் விபரம்",
    priority: "முன்னுரிமை",
    privacy: "தனியுரிமை",
    properties: "உடைமைகள்",
    ready: "தயார்",
    reject: " ிராகரி",
    release: "விடுவி",
    remove: "நீக்கு",
    removeAll: "அனைத்து நீக்க",
    reserved: "ஒதுக்கப்பட்டவை",
    resetFilters: "வடிகட்டல்களை மீட்டடமை",
    retry: "மீண்டும் முயற்சி செய்",
    revoke: "நீக்கு",
    revokeAll: "அனைத்தையும் நீக்கு",
    save: "சேமி",
    search: "தேடு",
    security: "பாதுகாப்பு",
    showAll: "அனைத்தையும் காட்டு",
    showLess: "சுருக்கிக் காண்",
    showMore: "மேலுங் காண்",
    showPassword: "கடவுச்சொல்லை காண்",
    startsWith: "தொடங்குவது",
    submit: "சமர்ப்பி",
    switch: "மாற்று",
    terminate: "முடி",
    terminateAll: "அனைத்தையும் முடி",
    terminateSession: "அமர்வை முடி",
    type: "வகை",
    update: "புதுப்பி",
    user: "பயனர்"
};

==> identity-apps-1.0.217-source-release.zip: identity-apps-1.0.217/modules/i18n/src/translations/ta-IN/portals/common.ts <==
/**
 * Copyright (c) 2020, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 * WSO2 Inc. licenses this file to you under the Apache License,
 * Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { CommonNS } from "../../../models";

export const common: CommonNS = {
    access: "அணுகல்",
    active: "செயல்பாட்டில் உள்ள",
    add: "சேர்",
    all: "அனைத்தும்",
    applicationName: "செயலியின் பெயர்",
    applications: "செயலிகள்",
    approvalStatus: "அனுமதி நிலை",
    approve: "அனுமதி",
    assignees: "அளிக்கப்பட்டவர்கள்",
    browser: "உலாவி",
    cancel: "இரத்து செய்",
    challengeQuestionNumber: "சவால் வினா {{number}}",
    change: "மாற்று",
    claim: "கோர்",
    close: "நெருக்கமான",
    completed: "பூரணப்படுத்தப்பட்டவை",
    configure: "கட்டமை",
    contains: "கொண்டுள்ளது",
    continue: "தொடர்",
    createdOn: "உருவாக்கப்பட்ட தினம்",
    dangerZone: "ஆபத்து மண்டலம்",
    delete: "அழி",
    description: "விபரம்",
    deviceModel: "கருவி மாதிரி",
    docs: "டாக்ஸ்",
    documentation: "ஆவணம்",
    done: "நிறைவு செய்",
    download: "பதிவிறக்கம்",
    edit: "திருத்து",
    endsWith: "முடிவடைவது",
    equals: "சமன்",
    filter: "வடிகட்டு",
    goBackHome: "முகப்புக்கு செல்",
    help: "உதவி",
    hidePassword: "கடவுச்சொல்லை மறை",
    identityProviders: "அடையாள வழங்குநர்கள்",
    initiator: "கருத்தா",
    ipAddress: "ip முகவரி",
    lastAccessed: "இறுதி அணுகல்",
    lastSeen: "இறுதி நுழைவு",
    loginTime: "நுழைந்த நேரம்",
    logout: "வெளியேறு",
    more: "மேலும்",
    myAccount: "என் கணக்கு",
    name: "பெயர்",
    operatingSystem: "இயங்கு தளம்",
    operations: "செயற்பாடுகள்",
    overview: "கண்ணோட்டம்",
    personalInfo: "பயனர் விபரம்",
    pin: "பொருத்து",
    pinned: "பொருத்தப்பட்டுள்ளது",
    priority: "முன்னுரிமை",
    privacy: "தனியுரிமை",
    properties: "உடைமைகள்",
    ready: "தயார்",
    reject: " ிராகரி",
    release: "விடுவி",
    remove: "நீக்கு",
    removeAll: "அனைத்து நீக்க",
    reserved: "ஒதுக்கப்பட்டவை",
    resetFilters: "வடிகட்டல்களை மீட்டடமை",
    retry: "மீண்டும் முயற்சி செய்",
    revoke: "நீக்கு",
    revokeAll: "அனைத்தையும் நீக்கு",
    samples: "மாதிரிகள்",
    save: "சேமி",
    services: "சேவைகள்",
    sdks: "SDKகள்",
    search: "தேடு",
    security: "பாதுகாப்பு",
    showAll: "அனைத்தையும் காட்டு",
    showLess: "சுருக்கிக் காண்",
    showMore: "மேலுங் காண்",
    showPassword: "கடவுச்சொல்லை காண்",
    startsWith: "தொடங்குவது",
    submit: "சமர்ப்பி",
    switch: "மாற்று",
    technologies: "தொழில்நுட்பங்கள்",
    terminate: "முடி",
    terminateAll: "அனைத்தையும் முடி",
    terminateSession: "அமர்வை முடி",
    type: "வகை",
    unpin: "அகற்று",
    unpinned: "அகற்றப்பட்டது",
    update: "புதுப்பி",
    user: "பயனர்",
    verify: "உறுதி செய்"
};
